pub fn analyse_play(trace: &PlayTrace) -> PlayAnalysisExpand description
Trace DD trick counts before and after each played card with
sys::AnalysePlayBin
Panics
Not expected — panics here are bugs. See the module-level panic policy.
pub fn analyse_play(trace: &PlayTrace) -> PlayAnalysisTrace DD trick counts before and after each played card with
sys::AnalysePlayBin
Not expected — panics here are bugs. See the module-level panic policy.