ParseHoldingError

Enum ParseHoldingError 

#[non_exhaustive]
pub enum ParseHoldingError { InvalidRanks, RepeatedRank, TooManyCards, }
An error which can be returned when parsing a Holding

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidRanks

Ranks are not all valid or in descending order



RepeatedRank

The same rank appears more than once



TooManyCards

A suit contains more than 13 cards