Hand

Struct Hand 

pub struct Hand(/* private fields */);
A hand of playing cards

Implementations

Source

impl Hand

pub const EMPTY: Self

The empty hand

pub const ALL: Self

The hand containing all 52 cards

pub const fn to_bits(self) -> u64

As a bitset of cards

pub const fn from_bits_retain(bits: u64) -> Self

Create a hand from a bitset of cards, retaining invalid cards

pub const fn contains_unknown_bits(self) -> bool

Whether the hand contains an invalid card

pub const fn from_bits(bits: u64) -> Option<Self>

Create a hand from a bitset of cards, checking for invalid cards

pub const fn from_bits_truncate(bits: u64) -> Self

Create a hand from a bitset of cards, removing invalid cards

pub const fn new( clubs: Holding, diamonds: Holding, hearts: Holding, spades: Holding, ) -> Self

Create a hand from four holdings in suit order (clubs, diamonds, hearts, spades)

pub const fn len(self) -> usize

The number of cards in the hand

pub const fn is_empty(self) -> bool

Whether the hand is empty

pub fn contains(self, card: Card) -> bool

Whether the hand contains a card

pub fn insert(&mut self, card: Card) -> bool

Insert a card into the hand, returning whether it was newly inserted

pub fn remove(&mut self, card: Card) -> bool

Remove a card from the hand, returning whether it was present

pub fn toggle(&mut self, card: Card) -> bool

Toggle a card in the hand, returning whether it is now present

pub fn set(&mut self, card: Card, condition: bool)

Conditionally insert/remove a card from the hand

pub const fn iter(self) -> HandIter

Iterate over the cards in the hand