Holding

Struct Holding 

pub struct Holding(/* private fields */);
A set of cards of the same suit

Implementations

Source

impl Holding

pub const EMPTY: Self

The empty set

pub const ALL: Self

The set containing all possible ranks (2..=14)

pub const fn len(self) -> usize

The number of cards in the holding

pub const fn is_empty(self) -> bool

Whether the holding is empty

pub const fn contains(self, rank: Rank) -> bool

Whether the holding contains a rank

pub const fn insert(&mut self, rank: Rank) -> bool

Insert a rank into the holding, returning whether it was newly inserted

pub const fn remove(&mut self, rank: Rank) -> bool

Remove a rank from the holding, returning whether it was present

pub const fn toggle(&mut self, rank: Rank) -> bool

Toggle a rank in the holding, returning whether it is now present

pub const fn set(&mut self, rank: Rank, condition: bool)

Conditionally insert/remove a rank from the holding

pub const fn iter(self) -> HoldingIter

Iterate over the ranks in the holding

pub const fn to_bits(self) -> u16

As a bitset of ranks

pub const fn from_bits_retain(bits: u16) -> Self

Create a holding from a bitset of ranks, retaining invalid ranks

pub const fn contains_unknown_bits(self) -> bool

Whether the holding contains an invalid rank

pub const fn from_bits(bits: u16) -> Option<Self>

Create a holding from a bitset of ranks, checking for invalid ranks

pub const fn from_bits_truncate(bits: u16) -> Self

Create a holding from a bitset of ranks, removing invalid ranks

pub const fn from_rank(rank: Rank) -> Self

Create a holding from a rank