#[non_exhaustive]pub enum BoardError {
PlayedCardInHand,
InconsistentHandSizes,
Revoke {
position: RevokePosition,
},
}Expand description
Error returned when constructing a Board with invalid invariants
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PlayedCardInHand
A card on the table is still present in one of the remaining hands
InconsistentHandSizes
The remaining hand sizes do not match the number of played cards
With k cards on the table, exactly the k seats starting from
leader (in playing order) must have one fewer card than the other
seats; all other seats must share a common size.
Revoke
A played card does not follow suit though the player held the led suit
Fields

position: RevokePositionPosition of the revoking card within the current trick