RevokePosition

Enum RevokePosition 

pub enum RevokePosition {
    Second,
    Third,
    Fourth,
}
Position of the revoking card within the current trick

The lead (first card) cannot revoke; these variants represent the subsequent seats in playing order.

Variants



Second

Second card of the trick (index 1)



Third

Third card of the trick (index 2)



Fourth

Fourth card of the trick (index 3)