TrickCountRow

Struct TrickCountRow 

pub struct TrickCountRow(/* private fields */);
Tricks that each seat can take as declarer for a strain

Implementations

Source

impl TrickCountRow

pub const fn new(n: u8, e: u8, s: u8, w: u8) -> Self

Create a new row from the number of tricks each seat can take

Panics

When any value is outside 0..=13. In const contexts, this is a compile-time error.

pub const fn try_new( n: u8, e: u8, s: u8, w: u8, ) -> Result<Self, InvalidTrickCount>

Try to create a new row from the number of tricks each seat can take

Errors

When any value is outside 0..=13.

pub const fn get(self, seat: Seat) -> TrickCount

Get the number of tricks a seat can take as declarer

pub const fn hex(self, seat: Seat) -> TrickCountRowHex

Hexadecimal representation from a seat’s perspective