pub struct Play {
pub card: Card,
pub equals: Holding,
pub score: TrickCount,
}Expand description
A play and its consequences
Fields
card: CardThe card to play, the highest in a sequence
For example, if the solution is to play a card from ♥KQJ, this field would be ♥K.
equals: HoldingLower equals in the sequence
Playing any card in a sequence is equal in bridge and many trick-taking
games. This field contains lower cards in the sequence as card. For
example, if the solution is to play KQJ, this field would contain QJ.
score: TrickCountTricks this play would score