PlayAnalysis

Struct PlayAnalysis 

pub struct PlayAnalysis {
    pub tricks: ArrayVec<TrickCount, 53>,
}
Double-dummy trick counts before and after each played card in a trace

Returned by analyse_play. Trick counts are from the declarer’s viewpoint: declarer is the right-hand opponent of the opening leader (the side to lead the very first trick in the starting Board).

tricks[0] is the DD value before any card in the trace is played. tricks[i] for i > 0 is the DD value after the i-th card. A drop from tricks[i - 1] to tricks[i] means that card was a double-dummy mistake by the side to move at the time.

Fields

tricks: ArrayVec<TrickCount, 53>

Trick counts — cards.len() + 1 entries, starting with the position before any card is played