pub struct Hand(/* private fields */);Expand description
A hand of playing cards
Implementations
Sourceimpl Hand
impl Hand
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Create a hand from a bitset of cards, retaining invalid cards
Sourcepub const fn contains_unknown_bits(self) -> bool
pub const fn contains_unknown_bits(self) -> bool
Whether the hand contains an invalid card
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Create a hand from a bitset of cards, checking for invalid cards
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Create a hand from a bitset of cards, removing invalid cards
Sourcepub const fn new(
clubs: Holding,
diamonds: Holding,
hearts: Holding,
spades: Holding,
) -> Self
pub const fn new( clubs: Holding, diamonds: Holding, hearts: Holding, spades: Holding, ) -> Self
Create a hand from four holdings in suit order (clubs, diamonds, hearts, spades)
Sourcepub fn insert(&mut self, card: Card) -> bool
pub fn insert(&mut self, card: Card) -> bool
Insert a card into the hand, returning whether it was newly inserted
Sourcepub fn remove(&mut self, card: Card) -> bool
pub fn remove(&mut self, card: Card) -> bool
Remove a card from the hand, returning whether it was present
Sourcepub fn toggle(&mut self, card: Card) -> bool
pub fn toggle(&mut self, card: Card) -> bool
Toggle a card in the hand, returning whether it is now present