pub struct Holding(/* private fields */);Expand description
A set of cards of the same suit
Implementations
Sourceimpl Holding
impl Holding
Sourcepub const fn insert(&mut self, rank: Rank) -> bool
pub const fn insert(&mut self, rank: Rank) -> bool
Insert a rank into the holding, returning whether it was newly inserted
Sourcepub const fn remove(&mut self, rank: Rank) -> bool
pub const fn remove(&mut self, rank: Rank) -> bool
Remove a rank from the holding, returning whether it was present
Sourcepub const fn toggle(&mut self, rank: Rank) -> bool
pub const fn toggle(&mut self, rank: Rank) -> bool
Toggle a rank in the holding, returning whether it is now present
Sourcepub const fn set(&mut self, rank: Rank, condition: bool)
pub const fn set(&mut self, rank: Rank, condition: bool)
Conditionally insert/remove a rank from the holding
Sourcepub const fn iter(self) -> HoldingIter ⓘ
pub const fn iter(self) -> HoldingIter ⓘ
Iterate over the ranks in the holding
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Create a holding from a bitset of ranks, retaining invalid ranks
Sourcepub const fn contains_unknown_bits(self) -> bool
pub const fn contains_unknown_bits(self) -> bool
Whether the holding contains an invalid rank
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Create a holding from a bitset of ranks, checking for invalid ranks
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Create a holding from a bitset of ranks, removing invalid ranks