pub struct TrickCountRow(/* private fields */);Expand description
Tricks that each seat can take as declarer for a strain
Implementations
Sourceimpl TrickCountRow
impl TrickCountRow
Sourcepub const fn new(n: u8, e: u8, s: u8, w: u8) -> Self
pub const fn new(n: u8, e: u8, s: u8, w: u8) -> Self
Create a new row from the number of tricks each seat can take
Panics
When any value is outside 0..=13. In const contexts, this is a
compile-time error.
Sourcepub const fn try_new(
n: u8,
e: u8,
s: u8,
w: u8,
) -> Result<Self, InvalidTrickCount>
pub const fn try_new( n: u8, e: u8, s: u8, w: u8, ) -> Result<Self, InvalidTrickCount>
Try to create a new row from the number of tricks each seat can take
Errors
When any value is outside 0..=13.
Sourcepub const fn get(self, seat: Seat) -> TrickCount
pub const fn get(self, seat: Seat) -> TrickCount
Get the number of tricks a seat can take as declarer
Sourcepub const fn hex(self, seat: Seat) -> TrickCountRowHex
pub const fn hex(self, seat: Seat) -> TrickCountRowHex
Hexadecimal representation from a seat’s perspective